require("config")

---------------------------------------------------------
-- Constants
local quarry_period = 60	-- how often to perform mining, in ticks
local mixed_ores = {"stone", "coal", "iron-ore", "copper-ore"}


---------------------------------------------------------
-- Process all ongoing events
function onTick()
	processQuarries()
end

---------------------------------------------------------
-- Initialize various objects
function onInit()
	global.deep_quarries = global.deep_quarries or {}
	script.on_event(defines.events.on_tick, onTick)
end
script.on_init(onInit)

---------------------------------------------------------
-- On reload, make sure that processing continues
function onLoad()
	script.on_event(defines.events.on_tick, onTick)
end
script.on_load(onLoad)

---------------------------------------------------------
-- Keep track of built objects
function builtEntity(event)
	local ent = event.created_entity
	local name = ent.name
	if name == "deep-quarry"then
		table.insert(global.deep_quarries, ent)
	end
end
script.on_event(defines.events.on_built_entity, builtEntity)
script.on_event(defines.events.on_robot_built_entity, builtEntity)

---------------------------------------------------------
-- Simulate mining in deep quarries
function processQuarries()
	if (game.tick % quarry_period == 0) then
		for index, quarry in pairs(global.deep_quarries) do
			if quarry and quarry.valid then
				local inventory = quarry.get_inventory(defines.inventory.item_main)
				if result_ore == "mixed" then
					ore = insertRandomOre(inventory, ore_per_second)
				else
					inventory.insert({name = result_ore, count = ore_per_second})
				end
			else
				table.remove(global.deep_quarries, index)
			end
		end
	end
end

---------------------------------------------------------
-- Random ore if the quarry gives "mixed" ore
function insertRandomOre(inventory)
	for i = 1, ore_per_second do
		inventory.insert({name = mixed_ores[math.random(1, #mixed_ores)], count = 1})
	end
end